import pandas as pd
import argparse

def score_predictions(true, pred, max_recs=50):
    """
    Score is a weighted sum of matching (user, item) pairs.
    Weights are based on eventtype: view - 1, contact - 5, favorite - 2, message - 2.
    """
    pred = pred.drop_duplicates(subset=['user_id', 'item_id'])
    pred['cnt'] = pred.groupby('user_id').cumcount()
    pred = pred[pred.cnt < max_recs]
    matches = pd.merge(true, pred, on=['user_id', 'item_id'])
    score = matches['weight'].sum()
    return score

if __name__=='__main__':
    parser = argparse.ArgumentParser()
    parser.add_argument('-r', '--recs' , help='path to recs')
    parser.add_argument('-t', '--true' , help='path to true data')
    args = parser.parse_args()
    recs = pd.read_csv(args.recs)
    true = pd.read_csv(args.true)
    print(score_predictions(true, recs))
